==> ejc-prjfinance-impl-3.0.1-20210727.084140-38-sources.jar: com/ejianc/business/prjfinance/bean/ProjectLoanEntity.java <==
package com.ejianc.business.prjfinance.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 项目借款
 * 
 * @author generator
 * 
 */
 @TableName("ejc_prjfinance_loan")
public class ProjectLoanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 主题
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="loan_money")
    private java.math.BigDecimal loanMoney; // 借款金额
    @TableField(value="return_money")
    private java.math.BigDecimal returnMoney; // 本单据累计已还金额
    @TableField(value="interest")
    private java.math.BigDecimal interest; // 本单据累计已结利息
    @TableField(value="agent_id")
    private Long agentId; // 经办人id
    @TableField(value="agent_name")
    private String agentName; // 经办人姓名
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="interest_type_id")
    private Long interestTypeId; // 计息方式id
    @TableField(value="interest_type_name")
    private String interestTypeName; // 计息方式名称
    @TableField(value="interest_memo")
    private String interestMemo; // 计息描述
    @TableField(value="year_interest")
    private java.math.BigDecimal yearInterest; // 年利率
    @TableField(value="start_interest")
    private java.util.Date startInterest; // 计息开始日期
    @TableField(value="plan_return_date")
    private java.util.Date planReturnDate; // 计划还款日期
    @TableField(value="process_date")
    private java.util.Date processDate; // 办理日期
    @TableField(value="total_loan_money")
    private java.math.BigDecimal totalLoanMoney; // 累计借款金额
    @TableField(value="total_return_money")
    private java.math.BigDecimal totalReturnMoney; // 累计还款金额
    @TableField(value="total_loan_balance")
    private java.math.BigDecimal totalLoanBalance; // 累计借款结余
    
    
    

    /**
     * 单据编号
     */
    public String getCode() {
        return code;
    }

    /**
     * 单据编号
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 主题
     */
    public String getName() {
        return name;
    }

    /**
     * 主题
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 借款金额
     */
    public java.math.BigDecimal getLoanMoney() {
        return loanMoney;
    }

    /**
     * 借款金额
     */
    public void setLoanMoney(java.math.BigDecimal loanMoney) {
        this.loanMoney = loanMoney;
    }
    /**
     * 已还金额
     */
    public java.math.BigDecimal getReturnMoney() {
        return returnMoney;
    }

    /**
     * 已还金额
     */
    public void setReturnMoney(java.math.BigDecimal returnMoney) {
        this.returnMoney = returnMoney;
    }
    /**
     * 已结利息
     */
    public java.math.BigDecimal getInterest() {
        return interest;
    }

    /**
     * 已结利息
     */
    public void setInterest(java.math.BigDecimal interest) {
        this.interest = interest;
    }
    /**
     * 经办人id
     */
    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 计息方式id
     */
    public Long getInterestTypeId() {
        return interestTypeId;
    }

    /**
     * 计息方式id
     */
    public void setInterestTypeId(Long interestTypeId) {
        this.interestTypeId = interestTypeId;
    }
    /**
     * 计息方式名称
     */
    public String getInterestTypeName() {
        return interestTypeName;
    }

    /**
     * 计息方式名称
     */
    public void setInterestTypeName(String interestTypeName) {
        this.interestTypeName = interestTypeName;
    }
    /**
     * 计息描述
     */
    public String getInterestMemo() {
        return interestMemo;
    }

    /**
     * 计息描述
     */
    public void setInterestMemo(String interestMemo) {
        this.interestMemo = interestMemo;
    }
    /**
     * 年利率
     */
    public java.math.BigDecimal getYearInterest() {
        return yearInterest;
    }

    /**
     * 年利率
     */
    public void setYearInterest(java.math.BigDecimal yearInterest) {
        this.yearInterest = yearInterest;
    }
    /**
     * 计息开始日期
     */
    public java.util.Date getStartInterest() {
        return startInterest;
    }

    /**
     * 计息开始日期
     */
    public void setStartInterest(java.util.Date startInterest) {
        this.startInterest = startInterest;
    }
    /**
     * 计划还款日期
     */
    public java.util.Date getPlanReturnDate() {
        return planReturnDate;
    }

    /**
     * 计划还款日期
     */
    public void setPlanReturnDate(java.util.Date planReturnDate) {
        this.planReturnDate = planReturnDate;
    }
    /**
     * 办理日期
     */
    public java.util.Date getProcessDate() {
        return processDate;
    }

    /**
     * 办理日期
     */
    public void setProcessDate(java.util.Date processDate) {
        this.processDate = processDate;
    }
    /**
     * 累计借款金额
     */
    public java.math.BigDecimal getTotalLoanMoney() {
        return totalLoanMoney;
    }

    /**
     * 累计借款金额
     */
    public void setTotalLoanMoney(java.math.BigDecimal totalLoanMoney) {
        this.totalLoanMoney = totalLoanMoney;
    }
    /**
     * 累计还款金额
     */
    public java.math.BigDecimal getTotalReturnMoney() {
        return totalReturnMoney;
    }

    /**
     * 累计还款金额
     */
    public void setTotalReturnMoney(java.math.BigDecimal totalReturnMoney) {
        this.totalReturnMoney = totalReturnMoney;
    }
    /**
     * 累计借款结余
     */
    public java.math.BigDecimal getTotalLoanBalance() {
        return totalLoanBalance;
    }

    /**
     * 累计借款结余
     */
    public void setTotalLoanBalance(java.math.BigDecimal totalLoanBalance) {
        this.totalLoanBalance = totalLoanBalance;
    }
    
}

==> ejc-prjfinance-impl-3.0.1-20210802.014925-57-sources.jar: com/ejianc/business/prjfinance/bean/ProjectLoanEntity.java <==
package com.ejianc.business.prjfinance.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 项目借款
 * 
 * @author generator
 * 
 */
 @TableName("ejc_prjfinance_loan")
public class ProjectLoanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 主题
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="loan_money")
    private java.math.BigDecimal loanMoney; // 借款金额
    @TableField(value="return_money")
    private java.math.BigDecimal returnMoney; // 本单据累计已还金额
    @TableField(value="interest")
    private java.math.BigDecimal interest; // 本单据累计已结利息
    @TableField(value="agent_id")
    private Long agentId; // 经办人id
    @TableField(value="agent_name")
    private String agentName; // 经办人姓名
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="interest_type_id")
    private Long interestTypeId; // 计息方式id
    @TableField(value="interest_type_name")
    private String interestTypeName; // 计息方式名称
    @TableField(value="interest_memo")
    private String interestMemo; // 计息描述
    @TableField(value="year_interest")
    private java.math.BigDecimal yearInterest; // 年利率
    @TableField(value="start_interest")
    private java.util.Date startInterest; // 计息开始日期
    @TableField(value="plan_return_date")
    private java.util.Date planReturnDate; // 计划还款日期
    @TableField(value="process_date")
    private java.util.Date processDate; // 办理日期
    @TableField(value="total_loan_money")
    private java.math.BigDecimal totalLoanMoney; // 累计借款金额
    @TableField(value="total_return_money")
    private java.math.BigDecimal totalReturnMoney; // 累计还款金额
    @TableField(value="total_loan_balance")
    private java.math.BigDecimal totalLoanBalance; // 累计借款结余

    @TableField(value="org_id")
    private Long orgId;
    

    /**
     * 单据编号
     */
    public String getCode() {
        return code;
    }

    /**
     * 单据编号
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 主题
     */
    public String getName() {
        return name;
    }

    /**
     * 主题
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 借款金额
     */
    public java.math.BigDecimal getLoanMoney() {
        return loanMoney;
    }

    /**
     * 借款金额
     */
    public void setLoanMoney(java.math.BigDecimal loanMoney) {
        this.loanMoney = loanMoney;
    }
    /**
     * 已还金额
     */
    public java.math.BigDecimal getReturnMoney() {
        return returnMoney;
    }

    /**
     * 已还金额
     */
    public void setReturnMoney(java.math.BigDecimal returnMoney) {
        this.returnMoney = returnMoney;
    }
    /**
     * 已结利息
     */
    public java.math.BigDecimal getInterest() {
        return interest;
    }

    /**
     * 已结利息
     */
    public void setInterest(java.math.BigDecimal interest) {
        this.interest = interest;
    }
    /**
     * 经办人id
     */
    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 计息方式id
     */
    public Long getInterestTypeId() {
        return interestTypeId;
    }

    /**
     * 计息方式id
     */
    public void setInterestTypeId(Long interestTypeId) {
        this.interestTypeId = interestTypeId;
    }
    /**
     * 计息方式名称
     */
    public String getInterestTypeName() {
        return interestTypeName;
    }

    /**
     * 计息方式名称
     */
    public void setInterestTypeName(String interestTypeName) {
        this.interestTypeName = interestTypeName;
    }
    /**
     * 计息描述
     */
    public String getInterestMemo() {
        return interestMemo;
    }

    /**
     * 计息描述
     */
    public void setInterestMemo(String interestMemo) {
        this.interestMemo = interestMemo;
    }
    /**
     * 年利率
     */
    public java.math.BigDecimal getYearInterest() {
        return yearInterest;
    }

    /**
     * 年利率
     */
    public void setYearInterest(java.math.BigDecimal yearInterest) {
        this.yearInterest = yearInterest;
    }
    /**
     * 计息开始日期
     */
    public java.util.Date getStartInterest() {
        return startInterest;
    }

    /**
     * 计息开始日期
     */
    public void setStartInterest(java.util.Date startInterest) {
        this.startInterest = startInterest;
    }
    /**
     * 计划还款日期
     */
    public java.util.Date getPlanReturnDate() {
        return planReturnDate;
    }

    /**
     * 计划还款日期
     */
    public void setPlanReturnDate(java.util.Date planReturnDate) {
        this.planReturnDate = planReturnDate;
    }
    /**
     * 办理日期
     */
    public java.util.Date getProcessDate() {
        return processDate;
    }

    /**
     * 办理日期
     */
    public void setProcessDate(java.util.Date processDate) {
        this.processDate = processDate;
    }
    /**
     * 累计借款金额
     */
    public java.math.BigDecimal getTotalLoanMoney() {
        return totalLoanMoney;
    }

    /**
     * 累计借款金额
     */
    public void setTotalLoanMoney(java.math.BigDecimal totalLoanMoney) {
        this.totalLoanMoney = totalLoanMoney;
    }
    /**
     * 累计还款金额
     */
    public java.math.BigDecimal getTotalReturnMoney() {
        return totalReturnMoney;
    }

    /**
     * 累计还款金额
     */
    public void setTotalReturnMoney(java.math.BigDecimal totalReturnMoney) {
        this.totalReturnMoney = totalReturnMoney;
    }
    /**
     * 累计借款结余
     */
    public java.math.BigDecimal getTotalLoanBalance() {
        return totalLoanBalance;
    }

    /**
     * 累计借款结余
     */
    public void setTotalLoanBalance(java.math.BigDecimal totalLoanBalance) {
        this.totalLoanBalance = totalLoanBalance;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
}
